==> cristalise-kernel-3.4.1-sources.jar: org/cristalise/kernel/scripting/ScriptLoadingException.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.scripting;

/**************************************************************************
 *
 * $Revision: 1.1 $
 * $Date: 2003/04/06 12:32:51 $
 *
 * Copyright (C) 2003 CERN - European Organization for Nuclear Research
 * All rights reserved.
 **************************************************************************/
public class ScriptLoadingException extends ScriptingEngineException {
  /**
     *
     */
    public ScriptLoadingException() {
        super();
    }
    /**
     *
     */
    public ScriptLoadingException(String msg) {
        super(msg);
    }
}

==> cristalise-kernel-3.7.0-sources.jar: org/cristalise/kernel/scripting/ScriptLoadingException.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.scripting;

public class ScriptLoadingException extends ScriptingEngineException {
    /**
     * 
     */
    private static final long serialVersionUID = 395106341865890224L;

    /**
     *
     */
    public ScriptLoadingException() {
        super();
    }
    /**
     *
     */
    public ScriptLoadingException(String msg) {
        super(msg);
    }

    public ScriptLoadingException(Throwable throwable) {
        super(throwable);
    }

    public ScriptLoadingException(String message, Throwable throwable) {
        super(message, throwable);
    }
}
